@@ -48,6 +48,9 @@
 #include "gnc-engine.h"
 #include "policy.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 typedef gnc_numeric (*xaccGetBalanceFn)( const Account *account );
 
 typedef gnc_numeric (*xaccGetBalanceInCurrencyFn) (
@@ -65,6 +68,12 @@ typedef struct
     QofInstanceClass parent_class;
 } AccountClass;
 
+typedef struct
+{
+    Account *acc;
+    QofBook *book;
+} GncImportMatchMap;
+
 /* --- type macros --- */
 #define GNC_TYPE_ACCOUNT            (gnc_account_get_type ())
 #define GNC_ACCOUNT(o)              \
@@ -100,36 +109,36 @@ typedef enum
 
     ACCT_TYPE_BANK = 0,	/**< The bank account type denotes a savings
 			 *   or checking account held at a bank.
-			 *   Often * interest * bearing. */
+			 *   Often interest bearing. */
     ACCT_TYPE_CASH = 1,	/**< The cash account type is used to denote a
 			 *   shoe-box or pillowcase stuffed with *
 			 *   cash. */
     ACCT_TYPE_CREDIT = 3,	/**< The Credit card account is used to denote
 			 *   credit (e.g. amex) and debit (e.g. visa,
-			 *   mastercard) * card accounts */
+			 *   mastercard) card accounts */
     ACCT_TYPE_ASSET = 2,	/**< asset (and liability) accounts indicate
 			 *   generic, generalized accounts that are
-			 *   none of the * above. */
+			 *   none of the above. */
     ACCT_TYPE_LIABILITY = 4,/**< liability (and asset) accounts indicate
 			   *   generic, generalized accounts that are
-			   *   none of the * above. */
+			   *   none of the above. */
     ACCT_TYPE_STOCK = 5,	/**< Stock accounts will typically be shown in
 			 *   registers which show three columns:
-			 *   price, number of * shares, and value. */
+			 *   price, number of shares, and value. */
     ACCT_TYPE_MUTUAL = 6,	/**< Mutual Fund accounts will typically be
 			 *   shown in registers which show three
-			 *   columns: price, * number of shares, and
+			 *   columns: price, number of shares, and
 			 *   value. */
     ACCT_TYPE_CURRENCY = 7,/**< The currency account type indicates that
 			  *   the account is a currency trading
-			  *   account.  In many * ways, a currency
+			  *   account.  In many ways, a currency
 			  *   trading account is like a stock *
 			  *   trading account. It is shown in the
-			  *   register with * three columns: price,
-			  *   number of shares, and * value. Note:
+			  *   register with three columns: price,
+			  *   number of shares, and value. Note:
 			  *   Since version 1.7.0, this account is *
 			  *   no longer needed to exchange currencies
-			  *   between * accounts, so this type is
+			  *   between accounts, so this type is
 			  *   DEPRECATED. */
     ACCT_TYPE_INCOME = 8,	/**< Income accounts are used to denote
 			 *   income */
@@ -293,6 +302,8 @@ void xaccAccountSetColor (Account *account, const char *color);
 void xaccAccountSetFilter (Account *account, const char *filter);
 /** Set the account's Sort Order */
 void xaccAccountSetSortOrder (Account *account, const char *sortorder);
+/** Set the account's Sort Order direction */
+void xaccAccountSetSortReversed (Account *account, gboolean sortreversed);
 /** Set the account's notes */
 void xaccAccountSetNotes (Account *account, const char *notes);
 /** Set the last num field of an Account */
@@ -384,6 +395,8 @@ const char * xaccAccountGetColor (const Account *account);
 const char * xaccAccountGetFilter (const Account *account);
 /** Get the account's Sort Order */
 const char * xaccAccountGetSortOrder (const Account *account);
+/** Get the account's Sort Order direction */
+gboolean xaccAccountGetSortReversed (const Account *account);
 /** Get the account's notes */
 const char * xaccAccountGetNotes (const Account *account);
 /** Get the last num field of an Account */
@@ -417,6 +430,17 @@ void xaccAccountSortSplits (Account *acc, gboolean force);
  */
 gchar * gnc_account_get_full_name (const Account *account);
 
+/** Retrieve the gains account used by this account for the indicated
+ * currency, creating and recording a new one if necessary.
+ *
+ * FIXME: There is at present no interface to designate an existing
+ * account, and the new account name is hard coded to
+ * "Orphaned Gains -- CUR"
+ *
+ * FIXME: There is no provision for creating separate accounts for
+ * anything other than currency, e.g. holding period of a security.
+ */
+Account * xaccAccountGainsAccount (Account *acc, gnc_commodity *curr);
 /** Set a string that identifies the Finance::Quote backend that
  *  should be used to retrieve online prices.  See price-quotes.scm
  *  for more information
@@ -431,18 +455,6 @@ void dxaccAccountSetPriceSrc (Account *account, const char *src);
  *  @deprecated Price quote information is now stored on the
  *  commodity, not the account. */
 const char * dxaccAccountGetPriceSrc (const Account *account);
-
-/** Returns a per-account flag: Prior to reconciling an account which
-    charges or pays interest, this flag tells whether to prompt the
-    user to enter a transaction for the interest charge or
-    payment. This per-account flag overrides the global preference. */
-gboolean xaccAccountGetAutoInterestXfer (const Account *account,
-        gboolean default_value);
-/** Sets a per-account flag: Prior to reconciling an account which
-    charges or pays interest, this flag tells whether to prompt the
-    user to enter a transaction for the interest charge or
-    payment. This per-account flag overrides the global preference. */
-void xaccAccountSetAutoInterestXfer (Account *account, gboolean value);
 /** @} */
 
 /** @name Account Commodity setters/getters
@@ -534,6 +546,9 @@ gnc_numeric xaccAccountGetProjectedMinimumBalance (const Account *account);
 gnc_numeric xaccAccountGetBalanceAsOfDate (Account *account,
         time64 date);
 
+/** Get the reconciled balance of the account as of the date specified */
+gnc_numeric xaccAccountGetReconciledBalanceAsOfDate (Account *account, time64 date);
+
 /* These two functions convert a given balance from one commodity to
    another.  The account argument is only used to get the Book, and
    may have nothing to do with the supplied balance.  Likewise, the
@@ -571,12 +586,19 @@ gnc_numeric xaccAccountGetProjectedMinimumBalanceInCurrency (
     const Account *account, const gnc_commodity *report_commodity,
     gboolean include_children);
 
+/* This function gets the balance as of the given date, ignoring
+   closing entries, in the desired commodity. */
+gnc_numeric xaccAccountGetNoclosingBalanceAsOfDateInCurrency(
+    Account *acc, time64 date, gnc_commodity *report_commodity,
+    gboolean include_children);
 /* This function gets the balance as of the given date in the desired
    commodity. */
 gnc_numeric xaccAccountGetBalanceAsOfDateInCurrency(
     Account *account, time64 date, gnc_commodity *report_commodity,
     gboolean include_children);
 
+gnc_numeric xaccAccountGetNoclosingBalanceChangeForPeriod (
+    Account *acc, time64 date1, time64 date2, gboolean recurse);
 gnc_numeric xaccAccountGetBalanceChangeForPeriod (
     Account *acc, time64 date1, time64 date2, gboolean recurse);
 
@@ -586,10 +608,7 @@ gnc_numeric xaccAccountGetBalanceChangeForPeriod (
 
  * The set of accounts is represented as a doubly-linked tree, so that given
  * any account, both its parent and its children can be easily found.
- * To make the management of sets of accounts easier, an account does not
- * directly point at its children, but rather at an 'Account Group' that
- * stores the children.  At the top of the tree hierarchy lies a single
- * root node, the root account group.
+ * At the top of the tree hierarchy lies a single root node, the root account.
  *
  * The account tree hierarchy is unique, in that a given account can
  * have only one parent account.
@@ -766,7 +785,7 @@ gint gnc_account_get_current_depth (const Account *account);
 
 /** Return the number of levels of descendants accounts below the
  *  specified account.  The returned number does not include the
- *  specifed account itself.
+ *  specified account itself.
  *
  *  @param account The account to query.
  *
@@ -863,8 +882,6 @@ gboolean xaccAccountGetReconcileChildrenStatus(const Account *account);
  */
 gboolean xaccAccountHasAncestor(const Account *acc, const Account *ancestor);
 
-#define xaccAccountGetSlots(X) qof_instance_get_slots(QOF_INSTANCE(X))
-
 /** @} */
 
 /** @name Lookup Accounts and Subaccounts by name or code
@@ -925,6 +942,11 @@ GNCAccountType xaccAccountStringToEnum (const char* str);
  *  to the local language. */
 const char * xaccAccountGetTypeStr (GNCAccountType type);
 
+/** Return the bitmask of account types compatible with a given type.
+ *  That is, you could switch to any of the account types in the compatible
+ *  list without unwanted side-effects. */
+guint32 xaccAccountTypesCompatibleWith (GNCAccountType type);
+
 /** Return the bitmask of parent account types compatible with a given type. */
 guint32 xaccParentAccountTypesCompatibleWith (GNCAccountType type);
 
@@ -937,6 +959,25 @@ gboolean xaccAccountTypesCompatible (GNCAccountType parent_type,
  *  root account types are stripped. */
 guint32 xaccAccountTypesValid(void);
 
+/** Convenience function to check if the account is a valid
+ *  Asset or Liability type, but not a business account type
+ *  (meaning not an Accounts Payable/Accounts Receivable). */
+gboolean xaccAccountIsAssetLiabType(GNCAccountType t);
+    
+/** Convenience function to return the fundamental type
+ * asset/liability/income/expense/equity given an account type. */
+GNCAccountType xaccAccountTypeGetFundamental (GNCAccountType t);
+
+
+/** Convenience function to check if the account is a valid
+ *  business account type
+ *  (meaning an Accounts Payable/Accounts Receivable). */
+gboolean xaccAccountIsAPARType(GNCAccountType t);
+
+/** Convenience function to check if the account is a valid
+ *  Equity type. */
+gboolean xaccAccountIsEquityType(GNCAccountType t);
+
 
 /** @} */
 
@@ -964,6 +1005,16 @@ guint32 xaccAccountTypesValid(void);
  */
 SplitList* xaccAccountGetSplitList (const Account *account);
 
+
+/** The xaccAccountCountSplits() routine returns the number of all
+ *    the splits in the account.
+ * @param acc the account for which to count the splits
+ *
+ * @param include_children also count splits in descendants (TRUE) or
+ *        for this account only (FALSE).
+ */
+gint64 xaccAccountCountSplits (const Account *acc, gboolean include_children);
+
 /** The xaccAccountMoveAllSplits() routine reassigns each of the splits
  *  in accfrom to accto. */
 void xaccAccountMoveAllSplits (Account *accfrom, Account *accto);
@@ -1160,6 +1211,29 @@ void xaccAccountSetHidden (Account *acc, gboolean val);
  *  @return Whether or not this account should be "hidden". */
 gboolean xaccAccountIsHidden (const Account *acc);
 /** @} */
+    
+/** @name Account Auto Interest flag
+ @{
+ */
+
+/** Get the "auto interest" flag for an account.  If this flag is set then
+ *  the account (and any children) will trigger an interest transfer after reconciling.
+ *
+ *  @param acc The account whose flag should be retrieved.
+ *
+ *  @return The current state of the account's "auto interest" flag. */
+gboolean xaccAccountGetAutoInterest (const Account *acc);
+
+/** Set the "auto interest" flag for an account.  If this flag is set then
+ *  the account (and any children) will trigger an interest transfer after reconciling.
+ *
+ *  @param acc The account whose flag should be retrieved.
+ *
+ *  @param val The new state for the account's "auto interest" flag. */
+void xaccAccountSetAutoInterest (Account *acc, gboolean val);
+
+/** @} */
+
 
 /** @name Account Tax related getters/setters
  @{
@@ -1183,6 +1257,17 @@ gint64 xaccAccountGetTaxUSCopyNumber (const Account *account);
 void xaccAccountSetTaxUSCopyNumber (Account *account, gint64 copy_number);
 /** @} */
 
+/** @name Account type debit/credit string getters
+ @ {      *
+ */
+
+/** Get the debit string associated with this account type */
+const char *gnc_account_get_debit_string (GNCAccountType acct_type);
+/** Get the credit string associated with this account type */
+const char *gnc_account_get_credit_string (GNCAccountType acct_type);
+
+/** @} */
+
 
 /** @name Account marking
 @{
@@ -1342,6 +1427,70 @@ int gnc_account_tree_staged_transaction_traversal(const Account *account,
 int xaccAccountTreeForEachTransaction(Account *acc,
                                       TransactionCallback proc, void *data);
 
+/** Obtain an ImportMatchMap object from an Account or a Book
+ */
+GncImportMatchMap *gnc_account_imap_create_imap (Account *acc);
+
+/* Look up an Account in the map non Baysian
+ */
+Account* gnc_account_imap_find_account (GncImportMatchMap *imap, const char* category,
+                                        const char *key);
+
+/* Store an Account in the map non Baysian
+ */
+void gnc_account_imap_add_account (GncImportMatchMap *imap, const char *category,
+                                   const char *key, Account *acc);
+
+/* Remove a reference to an Account in the map non Baysian
+ */
+void gnc_account_imap_delete_account (GncImportMatchMap *imap, const char *category,
+                                      const char *key);
+
+/** Look up an Account in the map using Baysian
+ */
+Account* gnc_account_imap_find_account_bayes (GncImportMatchMap *imap, GList* tokens);
+
+/** Updates the imap for a given account using a list of tokens
+ */
+void gnc_account_imap_add_account_bayes (GncImportMatchMap *imap, GList* tokens,
+                                         Account *acc);
+
+typedef struct imap_info
+{
+    Account        *source_account;
+    Account        *map_account;
+    GList          *list;
+    char           *head;
+    char           *category;
+    char           *match_string;
+    char           *count;
+}GncImapInfo;
+
+/** Returns a GList of structure imap_info of all Bayesian mappings for
+ *  required Account
+ */
+GList *gnc_account_imap_get_info_bayes (Account *acc);
+
+/** Returns a GList of structure imap_info of all Non Bayesian mappings for
+ *  required Account
+ */
+GList *gnc_account_imap_get_info (Account *acc, const char *category);
+
+/** Returns the text string pointed to by head and category for the Account, free
+ *  the returned text
+ */
+gchar *gnc_account_get_map_entry (Account *acc, const char *head, const char *category);
+
+/** Delete the entry for Account pointed to by head,category and match_string,
+ *  if empty is TRUE then use delete if empty
+ */
+void gnc_account_delete_map_entry (Account *acc, char *head, char *category,
+                                   char *match_string, gboolean empty);
+
+/** Delete all bayes entries for Account
+ */
+void gnc_account_delete_all_bayes_maps (Account *acc);
+
 /** @} */
 
 
@@ -1389,8 +1538,10 @@ const char * dxaccAccountGetQuoteTZ (const Account *account);
 #define ACCOUNT_COLOR_		"color"
 #define ACCOUNT_FILTER_		"filter"
 #define ACCOUNT_SORT_ORDER_	"sort-order"
+#define ACCOUNT_SORT_REVERSED_ "sort-reversed"
 #define ACCOUNT_NOTES_		"notes"
 #define ACCOUNT_BALANCE_	"balance"
+#define ACCOUNT_NOCLOSING_	"noclosing"
 #define ACCOUNT_CLEARED_	"cleared"
 #define ACCOUNT_RECONCILED_	"reconciled"
 #define ACCOUNT_PRESENT_	"present"
@@ -1407,6 +1558,10 @@ const char * dxaccAccountGetQuoteTZ (const Account *account);
  * in the gnome-search parameter list.  Be careful when you use this. */
 #define ACCOUNT_MATCH_ALL_TYPE	"account-match-all"
 
+#ifdef __cplusplus
+} /* extern "C" */
+#endif
+
 #endif /* XACC_ACCOUNT_H */
 /** @} */
 /** @} */
